@@ -10,18 +10,15 @@ end
 Foo.foo = 42
 Bar.new.foo = "str"
 
-# XXX: the output may be improved
-
 __END__
 # Classes
 module Foo
   self.@foo: Integer
 
-  attr_accessor foo: untyped
+  attr_accessor foo: String
   attr_accessor self.foo: Integer
 end
 
 class Bar
   include Foo
-  @foo: String
 end
