@@ -24,5 +24,5 @@ class A
   @str: String
   @val: (Integer | String)?
 
-  def initialize: ((Integer | String)? x) -> ((Integer | String)?)
+  def initialize: ((Integer | String)? x) -> void
 end
